==> aar_multi_chip-1.1.121-sources.jar: com/xdja/multichip/process/coveredcard/CCEventReceiver.java <==
package com.xdja.multichip.process.coveredcard;

import android.Manifest;
import android.app.Service;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.os.SystemClock;
import android.telephony.TelephonyManager;
import android.util.Log;

import com.xdja.multichip.MultiJniApiConfig;
import com.xdja.multichip.jniapi.JarMultiChipStatusManager;
import com.xdja.multichip.param.JniApiParam;
import com.xdja.multichip.process.SuperThreadRun;
import com.xdja.multichip.utils.FuncUtils;
import com.xdja.multichip.utils.PermissionUtil;

import java.util.ArrayList;
import java.util.List;

/**
 * @author: zhangxiaolong@xdja.com <br/>
 * date:   2018/5/16 <br/>
 */
public class CCEventReceiver extends BroadcastReceiver {
    private final static String TAG = CCEventReceiver.class.getSimpleName();
    private final static String ACTION_SIM_STATE_CHANGED = "android.intent.action.SIM_STATE_CHANGED";

    @Override
    public void onReceive(Context context, Intent intent) {
        if (intent == null) {
            Log.v("CC", "CCEventReceiver intent null");
            return;
        }

        //add by zhangxiaolong 2018-12-12 用于判断配置文件中是否允许启动子进程,目前先不杀死，之后研究如何杀死
        if (!MultiJniApiConfig.getInstance(context).judgeChipCanUse(CCChipForCall.NAME_PROCESS_CC)) {
            return;
        }

        //2018年7月24日11:04:34 weizg
        //安全接入反馈问题：同时又安全接入和芯片管家时，插拔tf卡，安全接入的tf receiver会收到广播，启动进程
        //再次插入后，该receiver依然会响应，会尝试打开卡，如果当前tf卡非支持多应用打开的cos，
        // 会出现芯片管家打不开的卡的情况

        //判断如果当前进程非芯片管家，并且芯片管家存在，则该receiver不做任何处理
        if (!FuncUtils.PKG_SAFE_KEYSERVICE.equals(context.getPackageName())
                && FuncUtils.isApkExist(context, FuncUtils.PKG_SAFE_KEYSERVICE)) {
            return;
        }

        if (ACTION_SIM_STATE_CHANGED.equals(intent.getAction())) {
            TelephonyManager tm = (TelephonyManager) context
                    .getSystemService(Service.TELEPHONY_SERVICE);
            int state = tm.getSimState();

            Log.w(TAG, "Sim state :" + state);

            switch (state) {
                case TelephonyManager.SIM_STATE_READY:
                case 6:
                    if (hasPermission(context.getApplicationContext())) {
                        JarMultiChipStatusManager.getInstance().sendCardStatus(context, "", JniApiParam.TYPE_COVERED, JarMultiChipStatusManager.CARD_STATUS_NOT_EXIST);
                        scanCC(context.getApplicationContext());
                    }
                    break;
                case TelephonyManager.SIM_STATE_ABSENT:
                    CCJniApiBinder.getInstance(context.getApplicationContext()).handleSimAbsent();
                    break;
                case TelephonyManager.SIM_STATE_UNKNOWN:
                case TelephonyManager.SIM_STATE_PIN_REQUIRED:
                case TelephonyManager.SIM_STATE_PUK_REQUIRED:
                case TelephonyManager.SIM_STATE_NETWORK_LOCKED:
                default:
                    break;
            }
        }
    }

    static int readyFlag = 0;

    private void scanCC(final Context context) {
        if (readyFlag == 1) {
            return;
        }
        readyFlag = 1;
        SuperThreadRun.service.submit(new Runnable() {
            @Override
            public void run() {
                SystemClock.sleep(7 * 1000);
                CCJniApiHandle.getInstance().getCurrentCoveredCardInfo(context);
                readyFlag = 0;
            }
        });

    }

    private boolean hasPermission(Context context) {

        List<String> permissions = new ArrayList<>();
        permissions.add(Manifest.permission.READ_SMS);
        permissions.add(Manifest.permission.SEND_SMS);
        permissions.add(Manifest.permission.RECEIVE_SMS);

        permissions.add(Manifest.permission.READ_CONTACTS);
        permissions.add(Manifest.permission.WRITE_CONTACTS);

        List<String> deniedPermissions = PermissionUtil.getDeniedPermissions(context, permissions);
        if (deniedPermissions.size() == 0) {
            return true;
        }
        return false;
    }
}

==> aar_multi_chip-1.1.216-sources.jar: com/xdja/multichip/process/coveredcard/CCEventReceiver.java <==
package com.xdja.multichip.process.coveredcard;

import android.Manifest;
import android.app.Service;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.os.SystemClock;
import android.telephony.TelephonyManager;
import android.util.Log;

import com.xdja.multichip.MultiJniApiConfig;
import com.xdja.multichip.jniapi.JarMultiChipStatusManager;
import com.xdja.multichip.param.JniApiParam;
import com.xdja.multichip.process.SuperThreadRun;
import com.xdja.multichip.utils.FuncUtils;
import com.xdja.multichip.utils.PermissionUtil;

import java.util.ArrayList;
import java.util.List;

/**
 * @author: zhangxiaolong@xdja.com <br/>
 * date:   2018/5/16 <br/>
 */
public class CCEventReceiver extends BroadcastReceiver {
    private static final String TAG = CCEventReceiver.class.getSimpleName();
    private static final String ACTION_SIM_STATE_CHANGED = "android.intent.action.SIM_STATE_CHANGED";

    @Override
    public void onReceive(Context context, Intent intent) {
        if (intent == null) {
            Log.v("CC", "CCEventReceiver intent null");
            return;
        }

        //add by zhangxiaolong 2018-12-12 用于判断配置文件中是否允许启动子进程,目前先不杀死，之后研究如何杀死
        if (!MultiJniApiConfig.getInstance(context).judgeChipCanUse(CCChipForCall.NAME_PROCESS_CC)) {
            return;
        }

        //2018年7月24日11:04:34 weizg
        //安全接入反馈问题：同时又安全接入和芯片管家时，插拔tf卡，安全接入的tf receiver会收到广播，启动进程
        //再次插入后，该receiver依然会响应，会尝试打开卡，如果当前tf卡非支持多应用打开的cos，
        // 会出现芯片管家打不开的卡的情况

        //判断如果当前进程非芯片管家，并且芯片管家存在，则该receiver不做任何处理
        if (!FuncUtils.PKG_SAFE_KEYSERVICE.equals(context.getPackageName())
                && FuncUtils.isApkExist(context, FuncUtils.PKG_SAFE_KEYSERVICE)) {
            return;
        }

        if (ACTION_SIM_STATE_CHANGED.equals(intent.getAction())) {
            TelephonyManager tm = (TelephonyManager) context
                    .getSystemService(Service.TELEPHONY_SERVICE);
            int state = tm.getSimState();

            Log.w(TAG, "Sim state :" + state);

            switch (state) {
                case TelephonyManager.SIM_STATE_READY:
                case 6:
                    if (CCPermission.hasPermission(context.getApplicationContext())) {
                        JarMultiChipStatusManager.getInstance().sendCardStatus(context, "", JniApiParam.TYPE_COVERED, JarMultiChipStatusManager.CARD_STATUS_NOT_EXIST);
                        scanCC(context.getApplicationContext());
                    }
                    break;
                case TelephonyManager.SIM_STATE_ABSENT:
                    CCJniApiBinder.getInstance(context.getApplicationContext()).handleSimAbsent();
                    break;
                case TelephonyManager.SIM_STATE_UNKNOWN:
                case TelephonyManager.SIM_STATE_PIN_REQUIRED:
                case TelephonyManager.SIM_STATE_PUK_REQUIRED:
                case TelephonyManager.SIM_STATE_NETWORK_LOCKED:
                default:
                    break;
            }
        }
    }

    private static int readyFlag = 0;

    private static void scanCC(final Context context) {
        if (readyFlag == 1) {
            return;
        }
        readyFlag = 1;
        SuperThreadRun.service.submit(new Runnable() {
            @Override
            public void run() {
                SystemClock.sleep(7 * 1000);
                CCJniApiHandle.getInstance().getCurrentCoveredCardInfo(context);
                readyFlag = 0;
            }
        });

    }

}
